aboutsummaryrefslogtreecommitdiff
path: root/src/go
diff options
context:
space:
mode:
authorRob Findley <rfindley@google.com>2021-04-28 14:40:53 -0400
committerRobert Findley <rfindley@google.com>2021-04-29 13:23:02 +0000
commit47cb0c46b206d3d1bcc176314c200e35c1f62cf2 (patch)
tree29e2a98809c44bcfe4b864bb962e30f0bfe62c0c /src/go
parentc4c68fb57f1b081557a837e8809094b42cfdc5e3 (diff)
downloadgo-47cb0c46b206d3d1bcc176314c200e35c1f62cf2.tar.gz
go-47cb0c46b206d3d1bcc176314c200e35c1f62cf2.zip
go/types: nest all test data under the testdata directory
Having multiple subdirectories of go/types containing test data is slightly problematic: - If ever we were to include a .go file in one of these directories, we'd inadvertently create a visible package. - It's difficult to add other content in testdata/, since TestTestdata scans the entire directory. Move everything down a level, into testdata/{fixedbugs,examples,check}, and update tests accordingly. Change-Id: Idd074c94b7b261d678934330539e41a48c2a9dc9 Reviewed-on: https://go-review.googlesource.com/c/go/+/314829 Trust: Robert Findley <rfindley@google.com> Trust: Robert Griesemer <gri@golang.org> Run-TryBot: Robert Findley <rfindley@google.com> TryBot-Result: Go Bot <gobot@golang.org> Reviewed-by: Robert Griesemer <gri@golang.org>
Diffstat (limited to 'src/go')
-rw-r--r--src/go/types/check_test.go12
-rw-r--r--src/go/types/testdata/check/blank.src (renamed from src/go/types/testdata/blank.src)0
-rw-r--r--src/go/types/testdata/check/builtins.go2 (renamed from src/go/types/testdata/builtins.go2)0
-rw-r--r--src/go/types/testdata/check/builtins.src (renamed from src/go/types/testdata/builtins.src)0
-rw-r--r--src/go/types/testdata/check/chans.go2 (renamed from src/go/types/testdata/chans.go2)0
-rw-r--r--src/go/types/testdata/check/const0.src (renamed from src/go/types/testdata/const0.src)0
-rw-r--r--src/go/types/testdata/check/const1.src (renamed from src/go/types/testdata/const1.src)0
-rw-r--r--src/go/types/testdata/check/constdecl.src (renamed from src/go/types/testdata/constdecl.src)0
-rw-r--r--src/go/types/testdata/check/conversions.src (renamed from src/go/types/testdata/conversions.src)0
-rw-r--r--src/go/types/testdata/check/conversions2.src (renamed from src/go/types/testdata/conversions2.src)0
-rw-r--r--src/go/types/testdata/check/cycles.src (renamed from src/go/types/testdata/cycles.src)0
-rw-r--r--src/go/types/testdata/check/cycles1.src (renamed from src/go/types/testdata/cycles1.src)0
-rw-r--r--src/go/types/testdata/check/cycles2.src (renamed from src/go/types/testdata/cycles2.src)0
-rw-r--r--src/go/types/testdata/check/cycles3.src (renamed from src/go/types/testdata/cycles3.src)0
-rw-r--r--src/go/types/testdata/check/cycles4.src (renamed from src/go/types/testdata/cycles4.src)0
-rw-r--r--src/go/types/testdata/check/cycles5.src (renamed from src/go/types/testdata/cycles5.src)0
-rw-r--r--src/go/types/testdata/check/decls0.src (renamed from src/go/types/testdata/decls0.src)0
-rw-r--r--src/go/types/testdata/check/decls1.src (renamed from src/go/types/testdata/decls1.src)0
-rw-r--r--src/go/types/testdata/check/decls2/decls2a.src (renamed from src/go/types/testdata/decls2/decls2a.src)0
-rw-r--r--src/go/types/testdata/check/decls2/decls2b.src (renamed from src/go/types/testdata/decls2/decls2b.src)0
-rw-r--r--src/go/types/testdata/check/decls3.src (renamed from src/go/types/testdata/decls3.src)0
-rw-r--r--src/go/types/testdata/check/decls4.src (renamed from src/go/types/testdata/decls4.src)0
-rw-r--r--src/go/types/testdata/check/decls5.src (renamed from src/go/types/testdata/decls5.src)0
-rw-r--r--src/go/types/testdata/check/errors.src (renamed from src/go/types/testdata/errors.src)0
-rw-r--r--src/go/types/testdata/check/expr0.src (renamed from src/go/types/testdata/expr0.src)0
-rw-r--r--src/go/types/testdata/check/expr1.src (renamed from src/go/types/testdata/expr1.src)0
-rw-r--r--src/go/types/testdata/check/expr2.src (renamed from src/go/types/testdata/expr2.src)0
-rw-r--r--src/go/types/testdata/check/expr3.src (renamed from src/go/types/testdata/expr3.src)0
-rw-r--r--src/go/types/testdata/check/go1_12.src (renamed from src/go/types/testdata/go1_12.src)0
-rw-r--r--src/go/types/testdata/check/go1_13.src (renamed from src/go/types/testdata/go1_13.src)0
-rw-r--r--src/go/types/testdata/check/go1_8.src (renamed from src/go/types/testdata/go1_8.src)0
-rw-r--r--src/go/types/testdata/check/gotos.src (renamed from src/go/types/testdata/gotos.src)0
-rw-r--r--src/go/types/testdata/check/importC.src (renamed from src/go/types/testdata/importC.src)0
-rw-r--r--src/go/types/testdata/check/importdecl0/importdecl0a.src (renamed from src/go/types/testdata/importdecl0/importdecl0a.src)0
-rw-r--r--src/go/types/testdata/check/importdecl0/importdecl0b.src (renamed from src/go/types/testdata/importdecl0/importdecl0b.src)0
-rw-r--r--src/go/types/testdata/check/importdecl1/importdecl1a.src (renamed from src/go/types/testdata/importdecl1/importdecl1a.src)0
-rw-r--r--src/go/types/testdata/check/importdecl1/importdecl1b.src (renamed from src/go/types/testdata/importdecl1/importdecl1b.src)0
-rw-r--r--src/go/types/testdata/check/init0.src (renamed from src/go/types/testdata/init0.src)0
-rw-r--r--src/go/types/testdata/check/init1.src (renamed from src/go/types/testdata/init1.src)0
-rw-r--r--src/go/types/testdata/check/init2.src (renamed from src/go/types/testdata/init2.src)0
-rw-r--r--src/go/types/testdata/check/issue25008/issue25008a.src (renamed from src/go/types/testdata/issue25008/issue25008a.src)0
-rw-r--r--src/go/types/testdata/check/issue25008/issue25008b.src (renamed from src/go/types/testdata/issue25008/issue25008b.src)0
-rw-r--r--src/go/types/testdata/check/issues.go2 (renamed from src/go/types/testdata/issues.go2)0
-rw-r--r--src/go/types/testdata/check/issues.src (renamed from src/go/types/testdata/issues.src)0
-rw-r--r--src/go/types/testdata/check/labels.src (renamed from src/go/types/testdata/labels.src)0
-rw-r--r--src/go/types/testdata/check/linalg.go2 (renamed from src/go/types/testdata/linalg.go2)0
-rw-r--r--src/go/types/testdata/check/literals.src (renamed from src/go/types/testdata/literals.src)0
-rw-r--r--src/go/types/testdata/check/main.src (renamed from src/go/types/testdata/main.src)0
-rw-r--r--src/go/types/testdata/check/map.go2 (renamed from src/go/types/testdata/map.go2)0
-rw-r--r--src/go/types/testdata/check/map2.go2 (renamed from src/go/types/testdata/map2.go2)0
-rw-r--r--src/go/types/testdata/check/methodsets.src (renamed from src/go/types/testdata/methodsets.src)0
-rw-r--r--src/go/types/testdata/check/shifts.src (renamed from src/go/types/testdata/shifts.src)0
-rw-r--r--src/go/types/testdata/check/slices.go2 (renamed from src/go/types/testdata/slices.go2)0
-rw-r--r--src/go/types/testdata/check/stmt0.src (renamed from src/go/types/testdata/stmt0.src)0
-rw-r--r--src/go/types/testdata/check/stmt1.src (renamed from src/go/types/testdata/stmt1.src)0
-rw-r--r--src/go/types/testdata/check/tinference.go2 (renamed from src/go/types/testdata/tinference.go2)0
-rw-r--r--src/go/types/testdata/check/tmp.go2 (renamed from src/go/types/testdata/tmp.go2)0
-rw-r--r--src/go/types/testdata/check/todos.go2 (renamed from src/go/types/testdata/todos.go2)0
-rw-r--r--src/go/types/testdata/check/typeinst.go2 (renamed from src/go/types/testdata/typeinst.go2)0
-rw-r--r--src/go/types/testdata/check/typeinst2.go2 (renamed from src/go/types/testdata/typeinst2.go2)0
-rw-r--r--src/go/types/testdata/check/typeparams.go2 (renamed from src/go/types/testdata/typeparams.go2)0
-rw-r--r--src/go/types/testdata/check/vardecl.src (renamed from src/go/types/testdata/vardecl.src)0
-rw-r--r--src/go/types/testdata/examples/functions.go2 (renamed from src/go/types/examples/functions.go2)0
-rw-r--r--src/go/types/testdata/examples/inference.go2 (renamed from src/go/types/examples/inference.go2)0
-rw-r--r--src/go/types/testdata/examples/methods.go2 (renamed from src/go/types/examples/methods.go2)0
-rw-r--r--src/go/types/testdata/examples/types.go2 (renamed from src/go/types/examples/types.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue20583.src (renamed from src/go/types/fixedbugs/issue20583.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue23203a.src (renamed from src/go/types/fixedbugs/issue23203a.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue23203b.src (renamed from src/go/types/fixedbugs/issue23203b.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue26390.src (renamed from src/go/types/fixedbugs/issue26390.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue28251.src (renamed from src/go/types/fixedbugs/issue28251.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39634.go2 (renamed from src/go/types/fixedbugs/issue39634.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39664.go2 (renamed from src/go/types/fixedbugs/issue39664.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39680.go2 (renamed from src/go/types/fixedbugs/issue39680.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39693.go2 (renamed from src/go/types/fixedbugs/issue39693.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39699.go2 (renamed from src/go/types/fixedbugs/issue39699.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39711.go2 (renamed from src/go/types/fixedbugs/issue39711.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39723.go2 (renamed from src/go/types/fixedbugs/issue39723.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39725.go2 (renamed from src/go/types/fixedbugs/issue39725.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39754.go2 (renamed from src/go/types/fixedbugs/issue39754.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39755.go2 (renamed from src/go/types/fixedbugs/issue39755.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39768.go2 (renamed from src/go/types/fixedbugs/issue39768.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39938.go2 (renamed from src/go/types/fixedbugs/issue39938.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39948.go2 (renamed from src/go/types/fixedbugs/issue39948.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39976.go2 (renamed from src/go/types/fixedbugs/issue39976.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue39982.go2 (renamed from src/go/types/fixedbugs/issue39982.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue40038.go2 (renamed from src/go/types/fixedbugs/issue40038.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue40056.go2 (renamed from src/go/types/fixedbugs/issue40056.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue40057.go2 (renamed from src/go/types/fixedbugs/issue40057.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue40301.go2 (renamed from src/go/types/fixedbugs/issue40301.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue40684.go2 (renamed from src/go/types/fixedbugs/issue40684.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue41124.go2 (renamed from src/go/types/fixedbugs/issue41124.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue42695.src (renamed from src/go/types/fixedbugs/issue42695.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue42758.go2 (renamed from src/go/types/fixedbugs/issue42758.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue43087.src (renamed from src/go/types/fixedbugs/issue43087.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue43110.src (renamed from src/go/types/fixedbugs/issue43110.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue43124.src (renamed from src/go/types/fixedbugs/issue43124.src)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue44688.go2 (renamed from src/go/types/fixedbugs/issue44688.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue44799.go2 (renamed from src/go/types/fixedbugs/issue44799.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue45548.go2 (renamed from src/go/types/fixedbugs/issue45548.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue45635.go2 (renamed from src/go/types/fixedbugs/issue45635.go2)0
-rw-r--r--src/go/types/testdata/fixedbugs/issue6977.src (renamed from src/go/types/fixedbugs/issue6977.src)0
102 files changed, 7 insertions, 5 deletions
diff --git a/src/go/types/testdata/blank.src b/src/go/types/testdata/check/blank.src
index 6a2507f482..6a2507f482 100644
--- a/src/go/types/testdata/blank.src
+++ b/src/go/types/testdata/check/blank.src
diff --git a/src/go/types/testdata/builtins.go2 b/src/go/types/testdata/check/builtins.go2
index 3918d836b5..3918d836b5 100644
--- a/src/go/types/testdata/builtins.go2
+++ b/src/go/types/testdata/check/builtins.go2
diff --git a/src/go/types/testdata/builtins.src b/src/go/types/testdata/check/builtins.src
index 3707528914..3707528914 100644
--- a/src/go/types/testdata/builtins.src
+++ b/src/go/types/testdata/check/builtins.src
diff --git a/src/go/types/testdata/chans.go2 b/src/go/types/testdata/check/chans.go2
index fad2bcec9d..fad2bcec9d 100644
--- a/src/go/types/testdata/chans.go2
+++ b/src/go/types/testdata/check/chans.go2
diff --git a/src/go/types/testdata/const0.src b/src/go/types/testdata/check/const0.src
index 5608b1549b..5608b1549b 100644
--- a/src/go/types/testdata/const0.src
+++ b/src/go/types/testdata/check/const0.src
diff --git a/src/go/types/testdata/const1.src b/src/go/types/testdata/check/const1.src
index 56b6bd4ca5..56b6bd4ca5 100644
--- a/src/go/types/testdata/const1.src
+++ b/src/go/types/testdata/check/const1.src
diff --git a/src/go/types/testdata/constdecl.src b/src/go/types/testdata/check/constdecl.src
index 680c85aff3..680c85aff3 100644
--- a/src/go/types/testdata/constdecl.src
+++ b/src/go/types/testdata/check/constdecl.src
diff --git a/src/go/types/testdata/conversions.src b/src/go/types/testdata/check/conversions.src
index e1336c0456..e1336c0456 100644
--- a/src/go/types/testdata/conversions.src
+++ b/src/go/types/testdata/check/conversions.src
diff --git a/src/go/types/testdata/conversions2.src b/src/go/types/testdata/check/conversions2.src
index 93a5f182fb..93a5f182fb 100644
--- a/src/go/types/testdata/conversions2.src
+++ b/src/go/types/testdata/check/conversions2.src
diff --git a/src/go/types/testdata/cycles.src b/src/go/types/testdata/check/cycles.src
index 218b4cad6a..218b4cad6a 100644
--- a/src/go/types/testdata/cycles.src
+++ b/src/go/types/testdata/check/cycles.src
diff --git a/src/go/types/testdata/cycles1.src b/src/go/types/testdata/check/cycles1.src
index ae2b38ebec..ae2b38ebec 100644
--- a/src/go/types/testdata/cycles1.src
+++ b/src/go/types/testdata/check/cycles1.src
diff --git a/src/go/types/testdata/cycles2.src b/src/go/types/testdata/check/cycles2.src
index 1a7f40ae4b..1a7f40ae4b 100644
--- a/src/go/types/testdata/cycles2.src
+++ b/src/go/types/testdata/check/cycles2.src
diff --git a/src/go/types/testdata/cycles3.src b/src/go/types/testdata/check/cycles3.src
index 5e89b627f0..5e89b627f0 100644
--- a/src/go/types/testdata/cycles3.src
+++ b/src/go/types/testdata/check/cycles3.src
diff --git a/src/go/types/testdata/cycles4.src b/src/go/types/testdata/check/cycles4.src
index 445babca68..445babca68 100644
--- a/src/go/types/testdata/cycles4.src
+++ b/src/go/types/testdata/check/cycles4.src
diff --git a/src/go/types/testdata/cycles5.src b/src/go/types/testdata/check/cycles5.src
index 397adcce01..397adcce01 100644
--- a/src/go/types/testdata/cycles5.src
+++ b/src/go/types/testdata/check/cycles5.src
diff --git a/src/go/types/testdata/decls0.src b/src/go/types/testdata/check/decls0.src
index 5ad8f53f65..5ad8f53f65 100644
--- a/src/go/types/testdata/decls0.src
+++ b/src/go/types/testdata/check/decls0.src
diff --git a/src/go/types/testdata/decls1.src b/src/go/types/testdata/check/decls1.src
index f4d2eaba91..f4d2eaba91 100644
--- a/src/go/types/testdata/decls1.src
+++ b/src/go/types/testdata/check/decls1.src
diff --git a/src/go/types/testdata/decls2/decls2a.src b/src/go/types/testdata/check/decls2/decls2a.src
index bdbecd9dbb..bdbecd9dbb 100644
--- a/src/go/types/testdata/decls2/decls2a.src
+++ b/src/go/types/testdata/check/decls2/decls2a.src
diff --git a/src/go/types/testdata/decls2/decls2b.src b/src/go/types/testdata/check/decls2/decls2b.src
index 5c55750a10..5c55750a10 100644
--- a/src/go/types/testdata/decls2/decls2b.src
+++ b/src/go/types/testdata/check/decls2/decls2b.src
diff --git a/src/go/types/testdata/decls3.src b/src/go/types/testdata/check/decls3.src
index 745175c710..745175c710 100644
--- a/src/go/types/testdata/decls3.src
+++ b/src/go/types/testdata/check/decls3.src
diff --git a/src/go/types/testdata/decls4.src b/src/go/types/testdata/check/decls4.src
index 140bbfd31f..140bbfd31f 100644
--- a/src/go/types/testdata/decls4.src
+++ b/src/go/types/testdata/check/decls4.src
diff --git a/src/go/types/testdata/decls5.src b/src/go/types/testdata/check/decls5.src
index 88d31946da..88d31946da 100644
--- a/src/go/types/testdata/decls5.src
+++ b/src/go/types/testdata/check/decls5.src
diff --git a/src/go/types/testdata/errors.src b/src/go/types/testdata/check/errors.src
index ff929217c4..ff929217c4 100644
--- a/src/go/types/testdata/errors.src
+++ b/src/go/types/testdata/check/errors.src
diff --git a/src/go/types/testdata/expr0.src b/src/go/types/testdata/check/expr0.src
index 1aac726327..1aac726327 100644
--- a/src/go/types/testdata/expr0.src
+++ b/src/go/types/testdata/check/expr0.src
diff --git a/src/go/types/testdata/expr1.src b/src/go/types/testdata/check/expr1.src
index 4ead815158..4ead815158 100644
--- a/src/go/types/testdata/expr1.src
+++ b/src/go/types/testdata/check/expr1.src
diff --git a/src/go/types/testdata/expr2.src b/src/go/types/testdata/check/expr2.src
index 0c959e8011..0c959e8011 100644
--- a/src/go/types/testdata/expr2.src
+++ b/src/go/types/testdata/check/expr2.src
diff --git a/src/go/types/testdata/expr3.src b/src/go/types/testdata/check/expr3.src
index 0525a5a33a..0525a5a33a 100644
--- a/src/go/types/testdata/expr3.src
+++ b/src/go/types/testdata/check/expr3.src
diff --git a/src/go/types/testdata/go1_12.src b/src/go/types/testdata/check/go1_12.src
index 1e529f18be..1e529f18be 100644
--- a/src/go/types/testdata/go1_12.src
+++ b/src/go/types/testdata/check/go1_12.src
diff --git a/src/go/types/testdata/go1_13.src b/src/go/types/testdata/check/go1_13.src
index 6aa1364e8a..6aa1364e8a 100644
--- a/src/go/types/testdata/go1_13.src
+++ b/src/go/types/testdata/check/go1_13.src
diff --git a/src/go/types/testdata/go1_8.src b/src/go/types/testdata/check/go1_8.src
index 3ead1e981b..3ead1e981b 100644
--- a/src/go/types/testdata/go1_8.src
+++ b/src/go/types/testdata/check/go1_8.src
diff --git a/src/go/types/testdata/gotos.src b/src/go/types/testdata/check/gotos.src
index 069a94bbbf..069a94bbbf 100644
--- a/src/go/types/testdata/gotos.src
+++ b/src/go/types/testdata/check/gotos.src
diff --git a/src/go/types/testdata/importC.src b/src/go/types/testdata/check/importC.src
index f55be2d5c5..f55be2d5c5 100644
--- a/src/go/types/testdata/importC.src
+++ b/src/go/types/testdata/check/importC.src
diff --git a/src/go/types/testdata/importdecl0/importdecl0a.src b/src/go/types/testdata/check/importdecl0/importdecl0a.src
index 5ceb96e1fa..5ceb96e1fa 100644
--- a/src/go/types/testdata/importdecl0/importdecl0a.src
+++ b/src/go/types/testdata/check/importdecl0/importdecl0a.src
diff --git a/src/go/types/testdata/importdecl0/importdecl0b.src b/src/go/types/testdata/check/importdecl0/importdecl0b.src
index 55690423b6..55690423b6 100644
--- a/src/go/types/testdata/importdecl0/importdecl0b.src
+++ b/src/go/types/testdata/check/importdecl0/importdecl0b.src
diff --git a/src/go/types/testdata/importdecl1/importdecl1a.src b/src/go/types/testdata/check/importdecl1/importdecl1a.src
index d377c01638..d377c01638 100644
--- a/src/go/types/testdata/importdecl1/importdecl1a.src
+++ b/src/go/types/testdata/check/importdecl1/importdecl1a.src
diff --git a/src/go/types/testdata/importdecl1/importdecl1b.src b/src/go/types/testdata/check/importdecl1/importdecl1b.src
index 43a7bcd753..43a7bcd753 100644
--- a/src/go/types/testdata/importdecl1/importdecl1b.src
+++ b/src/go/types/testdata/check/importdecl1/importdecl1b.src
diff --git a/src/go/types/testdata/init0.src b/src/go/types/testdata/check/init0.src
index 6e8746afb6..6e8746afb6 100644
--- a/src/go/types/testdata/init0.src
+++ b/src/go/types/testdata/check/init0.src
diff --git a/src/go/types/testdata/init1.src b/src/go/types/testdata/check/init1.src
index 39ca31466b..39ca31466b 100644
--- a/src/go/types/testdata/init1.src
+++ b/src/go/types/testdata/check/init1.src
diff --git a/src/go/types/testdata/init2.src b/src/go/types/testdata/check/init2.src
index 614db6c949..614db6c949 100644
--- a/src/go/types/testdata/init2.src
+++ b/src/go/types/testdata/check/init2.src
diff --git a/src/go/types/testdata/issue25008/issue25008a.src b/src/go/types/testdata/check/issue25008/issue25008a.src
index cf71ca10e4..cf71ca10e4 100644
--- a/src/go/types/testdata/issue25008/issue25008a.src
+++ b/src/go/types/testdata/check/issue25008/issue25008a.src
diff --git a/src/go/types/testdata/issue25008/issue25008b.src b/src/go/types/testdata/check/issue25008/issue25008b.src
index f132b7fab3..f132b7fab3 100644
--- a/src/go/types/testdata/issue25008/issue25008b.src
+++ b/src/go/types/testdata/check/issue25008/issue25008b.src
diff --git a/src/go/types/testdata/issues.go2 b/src/go/types/testdata/check/issues.go2
index 8994164eac..8994164eac 100644
--- a/src/go/types/testdata/issues.go2
+++ b/src/go/types/testdata/check/issues.go2
diff --git a/src/go/types/testdata/issues.src b/src/go/types/testdata/check/issues.src
index e2ac06759b..e2ac06759b 100644
--- a/src/go/types/testdata/issues.src
+++ b/src/go/types/testdata/check/issues.src
diff --git a/src/go/types/testdata/labels.src b/src/go/types/testdata/check/labels.src
index 9f42406965..9f42406965 100644
--- a/src/go/types/testdata/labels.src
+++ b/src/go/types/testdata/check/labels.src
diff --git a/src/go/types/testdata/linalg.go2 b/src/go/types/testdata/check/linalg.go2
index 0d27603a58..0d27603a58 100644
--- a/src/go/types/testdata/linalg.go2
+++ b/src/go/types/testdata/check/linalg.go2
diff --git a/src/go/types/testdata/literals.src b/src/go/types/testdata/check/literals.src
index 494a465f48..494a465f48 100644
--- a/src/go/types/testdata/literals.src
+++ b/src/go/types/testdata/check/literals.src
diff --git a/src/go/types/testdata/main.src b/src/go/types/testdata/check/main.src
index f892938d4a..f892938d4a 100644
--- a/src/go/types/testdata/main.src
+++ b/src/go/types/testdata/check/main.src
diff --git a/src/go/types/testdata/map.go2 b/src/go/types/testdata/check/map.go2
index 814d9539fd..814d9539fd 100644
--- a/src/go/types/testdata/map.go2
+++ b/src/go/types/testdata/check/map.go2
diff --git a/src/go/types/testdata/map2.go2 b/src/go/types/testdata/check/map2.go2
index 2833445662..2833445662 100644
--- a/src/go/types/testdata/map2.go2
+++ b/src/go/types/testdata/check/map2.go2
diff --git a/src/go/types/testdata/methodsets.src b/src/go/types/testdata/check/methodsets.src
index 9fb10deb9a..9fb10deb9a 100644
--- a/src/go/types/testdata/methodsets.src
+++ b/src/go/types/testdata/check/methodsets.src
diff --git a/src/go/types/testdata/shifts.src b/src/go/types/testdata/check/shifts.src
index 4d3c59a50f..4d3c59a50f 100644
--- a/src/go/types/testdata/shifts.src
+++ b/src/go/types/testdata/check/shifts.src
diff --git a/src/go/types/testdata/slices.go2 b/src/go/types/testdata/check/slices.go2
index 2bacd1c2aa..2bacd1c2aa 100644
--- a/src/go/types/testdata/slices.go2
+++ b/src/go/types/testdata/check/slices.go2
diff --git a/src/go/types/testdata/stmt0.src b/src/go/types/testdata/check/stmt0.src
index 76b6e70d63..76b6e70d63 100644
--- a/src/go/types/testdata/stmt0.src
+++ b/src/go/types/testdata/check/stmt0.src
diff --git a/src/go/types/testdata/stmt1.src b/src/go/types/testdata/check/stmt1.src
index f79f92058b..f79f92058b 100644
--- a/src/go/types/testdata/stmt1.src
+++ b/src/go/types/testdata/check/stmt1.src
diff --git a/src/go/types/testdata/tinference.go2 b/src/go/types/testdata/check/tinference.go2
index 31338b33ad..31338b33ad 100644
--- a/src/go/types/testdata/tinference.go2
+++ b/src/go/types/testdata/check/tinference.go2
diff --git a/src/go/types/testdata/tmp.go2 b/src/go/types/testdata/check/tmp.go2
index dae78caff8..dae78caff8 100644
--- a/src/go/types/testdata/tmp.go2
+++ b/src/go/types/testdata/check/tmp.go2
diff --git a/src/go/types/testdata/todos.go2 b/src/go/types/testdata/check/todos.go2
index 09e9b4c48a..09e9b4c48a 100644
--- a/src/go/types/testdata/todos.go2
+++ b/src/go/types/testdata/check/todos.go2
diff --git a/src/go/types/testdata/typeinst.go2 b/src/go/types/testdata/check/typeinst.go2
index 3184a4b5b1..3184a4b5b1 100644
--- a/src/go/types/testdata/typeinst.go2
+++ b/src/go/types/testdata/check/typeinst.go2
diff --git a/src/go/types/testdata/typeinst2.go2 b/src/go/types/testdata/check/typeinst2.go2
index 6e2104a515..6e2104a515 100644
--- a/src/go/types/testdata/typeinst2.go2
+++ b/src/go/types/testdata/check/typeinst2.go2
diff --git a/src/go/types/testdata/typeparams.go2 b/src/go/types/testdata/check/typeparams.go2
index d95e02e443..d95e02e443 100644
--- a/src/go/types/testdata/typeparams.go2
+++ b/src/go/types/testdata/check/typeparams.go2
diff --git a/src/go/types/testdata/vardecl.src b/src/go/types/testdata/check/vardecl.src
index 54f5ef1e10..54f5ef1e10 100644
--- a/src/go/types/testdata/vardecl.src
+++ b/src/go/types/testdata/check/vardecl.src
diff --git a/src/go/types/examples/functions.go2 b/src/go/types/testdata/examples/functions.go2
index fb74ae7ae2..fb74ae7ae2 100644
--- a/src/go/types/examples/functions.go2
+++ b/src/go/types/testdata/examples/functions.go2
diff --git a/src/go/types/examples/inference.go2 b/src/go/types/testdata/examples/inference.go2
index b4f3369aa0..b4f3369aa0 100644
--- a/src/go/types/examples/inference.go2
+++ b/src/go/types/testdata/examples/inference.go2
diff --git a/src/go/types/examples/methods.go2 b/src/go/types/testdata/examples/methods.go2
index 76c6539e1b..76c6539e1b 100644
--- a/src/go/types/examples/methods.go2
+++ b/src/go/types/testdata/examples/methods.go2
diff --git a/src/go/types/examples/types.go2 b/src/go/types/testdata/examples/types.go2
index 59c8804ad2..59c8804ad2 100644
--- a/src/go/types/examples/types.go2
+++ b/src/go/types/testdata/examples/types.go2
diff --git a/src/go/types/fixedbugs/issue20583.src b/src/go/types/testdata/fixedbugs/issue20583.src
index d26dbada4f..d26dbada4f 100644
--- a/src/go/types/fixedbugs/issue20583.src
+++ b/src/go/types/testdata/fixedbugs/issue20583.src
diff --git a/src/go/types/fixedbugs/issue23203a.src b/src/go/types/testdata/fixedbugs/issue23203a.src
index 48cb5889cd..48cb5889cd 100644
--- a/src/go/types/fixedbugs/issue23203a.src
+++ b/src/go/types/testdata/fixedbugs/issue23203a.src
diff --git a/src/go/types/fixedbugs/issue23203b.src b/src/go/types/testdata/fixedbugs/issue23203b.src
index 638ec6c5ce..638ec6c5ce 100644
--- a/src/go/types/fixedbugs/issue23203b.src
+++ b/src/go/types/testdata/fixedbugs/issue23203b.src
diff --git a/src/go/types/fixedbugs/issue26390.src b/src/go/types/testdata/fixedbugs/issue26390.src
index 9e0101f581..9e0101f581 100644
--- a/src/go/types/fixedbugs/issue26390.src
+++ b/src/go/types/testdata/fixedbugs/issue26390.src
diff --git a/src/go/types/fixedbugs/issue28251.src b/src/go/types/testdata/fixedbugs/issue28251.src
index cd79e0e8b5..cd79e0e8b5 100644
--- a/src/go/types/fixedbugs/issue28251.src
+++ b/src/go/types/testdata/fixedbugs/issue28251.src
diff --git a/src/go/types/fixedbugs/issue39634.go2 b/src/go/types/testdata/fixedbugs/issue39634.go2
index a13ed13ce5..a13ed13ce5 100644
--- a/src/go/types/fixedbugs/issue39634.go2
+++ b/src/go/types/testdata/fixedbugs/issue39634.go2
diff --git a/src/go/types/fixedbugs/issue39664.go2 b/src/go/types/testdata/fixedbugs/issue39664.go2
index 3b3ec56980..3b3ec56980 100644
--- a/src/go/types/fixedbugs/issue39664.go2
+++ b/src/go/types/testdata/fixedbugs/issue39664.go2
diff --git a/src/go/types/fixedbugs/issue39680.go2 b/src/go/types/testdata/fixedbugs/issue39680.go2
index 9bc26f3546..9bc26f3546 100644
--- a/src/go/types/fixedbugs/issue39680.go2
+++ b/src/go/types/testdata/fixedbugs/issue39680.go2
diff --git a/src/go/types/fixedbugs/issue39693.go2 b/src/go/types/testdata/fixedbugs/issue39693.go2
index 316ab1982e..316ab1982e 100644
--- a/src/go/types/fixedbugs/issue39693.go2
+++ b/src/go/types/testdata/fixedbugs/issue39693.go2
diff --git a/src/go/types/fixedbugs/issue39699.go2 b/src/go/types/testdata/fixedbugs/issue39699.go2
index 75491e7e26..75491e7e26 100644
--- a/src/go/types/fixedbugs/issue39699.go2
+++ b/src/go/types/testdata/fixedbugs/issue39699.go2
diff --git a/src/go/types/fixedbugs/issue39711.go2 b/src/go/types/testdata/fixedbugs/issue39711.go2
index df621a4c17..df621a4c17 100644
--- a/src/go/types/fixedbugs/issue39711.go2
+++ b/src/go/types/testdata/fixedbugs/issue39711.go2
diff --git a/src/go/types/fixedbugs/issue39723.go2 b/src/go/types/testdata/fixedbugs/issue39723.go2
index 55464e6b77..55464e6b77 100644
--- a/src/go/types/fixedbugs/issue39723.go2
+++ b/src/go/types/testdata/fixedbugs/issue39723.go2
diff --git a/src/go/types/fixedbugs/issue39725.go2 b/src/go/types/testdata/fixedbugs/issue39725.go2
index e19b6770bf..e19b6770bf 100644
--- a/src/go/types/fixedbugs/issue39725.go2
+++ b/src/go/types/testdata/fixedbugs/issue39725.go2
diff --git a/src/go/types/fixedbugs/issue39754.go2 b/src/go/types/testdata/fixedbugs/issue39754.go2
index 4b4420d997..4b4420d997 100644
--- a/src/go/types/fixedbugs/issue39754.go2
+++ b/src/go/types/testdata/fixedbugs/issue39754.go2
diff --git a/src/go/types/fixedbugs/issue39755.go2 b/src/go/types/testdata/fixedbugs/issue39755.go2
index b7ab68818e..b7ab68818e 100644
--- a/src/go/types/fixedbugs/issue39755.go2
+++ b/src/go/types/testdata/fixedbugs/issue39755.go2
diff --git a/src/go/types/fixedbugs/issue39768.go2 b/src/go/types/testdata/fixedbugs/issue39768.go2
index abac141d7f..abac141d7f 100644
--- a/src/go/types/fixedbugs/issue39768.go2
+++ b/src/go/types/testdata/fixedbugs/issue39768.go2
diff --git a/src/go/types/fixedbugs/issue39938.go2 b/src/go/types/testdata/fixedbugs/issue39938.go2
index 76e7e369ca..76e7e369ca 100644
--- a/src/go/types/fixedbugs/issue39938.go2
+++ b/src/go/types/testdata/fixedbugs/issue39938.go2
diff --git a/src/go/types/fixedbugs/issue39948.go2 b/src/go/types/testdata/fixedbugs/issue39948.go2
index c2b460902c..c2b460902c 100644
--- a/src/go/types/fixedbugs/issue39948.go2
+++ b/src/go/types/testdata/fixedbugs/issue39948.go2
diff --git a/src/go/types/fixedbugs/issue39976.go2 b/src/go/types/testdata/fixedbugs/issue39976.go2
index 3db4eae012..3db4eae012 100644
--- a/src/go/types/fixedbugs/issue39976.go2
+++ b/src/go/types/testdata/fixedbugs/issue39976.go2
diff --git a/src/go/types/fixedbugs/issue39982.go2 b/src/go/types/testdata/fixedbugs/issue39982.go2
index 9810b6386a..9810b6386a 100644
--- a/src/go/types/fixedbugs/issue39982.go2
+++ b/src/go/types/testdata/fixedbugs/issue39982.go2
diff --git a/src/go/types/fixedbugs/issue40038.go2 b/src/go/types/testdata/fixedbugs/issue40038.go2
index 8948d61caa..8948d61caa 100644
--- a/src/go/types/fixedbugs/issue40038.go2
+++ b/src/go/types/testdata/fixedbugs/issue40038.go2
diff --git a/src/go/types/fixedbugs/issue40056.go2 b/src/go/types/testdata/fixedbugs/issue40056.go2
index f587691e3d..f587691e3d 100644
--- a/src/go/types/fixedbugs/issue40056.go2
+++ b/src/go/types/testdata/fixedbugs/issue40056.go2
diff --git a/src/go/types/fixedbugs/issue40057.go2 b/src/go/types/testdata/fixedbugs/issue40057.go2
index fdc8fb1c00..fdc8fb1c00 100644
--- a/src/go/types/fixedbugs/issue40057.go2
+++ b/src/go/types/testdata/fixedbugs/issue40057.go2
diff --git a/src/go/types/fixedbugs/issue40301.go2 b/src/go/types/testdata/fixedbugs/issue40301.go2
index 5d97855f8a..5d97855f8a 100644
--- a/src/go/types/fixedbugs/issue40301.go2
+++ b/src/go/types/testdata/fixedbugs/issue40301.go2
diff --git a/src/go/types/fixedbugs/issue40684.go2 b/src/go/types/testdata/fixedbugs/issue40684.go2
index 0269c3a62c..0269c3a62c 100644
--- a/src/go/types/fixedbugs/issue40684.go2
+++ b/src/go/types/testdata/fixedbugs/issue40684.go2
diff --git a/src/go/types/fixedbugs/issue41124.go2 b/src/go/types/testdata/fixedbugs/issue41124.go2
index 61f766bcbd..61f766bcbd 100644
--- a/src/go/types/fixedbugs/issue41124.go2
+++ b/src/go/types/testdata/fixedbugs/issue41124.go2
diff --git a/src/go/types/fixedbugs/issue42695.src b/src/go/types/testdata/fixedbugs/issue42695.src
index d0d6200969..d0d6200969 100644
--- a/src/go/types/fixedbugs/issue42695.src
+++ b/src/go/types/testdata/fixedbugs/issue42695.src
diff --git a/src/go/types/fixedbugs/issue42758.go2 b/src/go/types/testdata/fixedbugs/issue42758.go2
index 698cb8a16b..698cb8a16b 100644
--- a/src/go/types/fixedbugs/issue42758.go2
+++ b/src/go/types/testdata/fixedbugs/issue42758.go2
diff --git a/src/go/types/fixedbugs/issue43087.src b/src/go/types/testdata/fixedbugs/issue43087.src
index ef37b4aa29..ef37b4aa29 100644
--- a/src/go/types/fixedbugs/issue43087.src
+++ b/src/go/types/testdata/fixedbugs/issue43087.src
diff --git a/src/go/types/fixedbugs/issue43110.src b/src/go/types/testdata/fixedbugs/issue43110.src
index 4a46945239..4a46945239 100644
--- a/src/go/types/fixedbugs/issue43110.src
+++ b/src/go/types/testdata/fixedbugs/issue43110.src
diff --git a/src/go/types/fixedbugs/issue43124.src b/src/go/types/testdata/fixedbugs/issue43124.src
index f429f74a74..f429f74a74 100644
--- a/src/go/types/fixedbugs/issue43124.src
+++ b/src/go/types/testdata/fixedbugs/issue43124.src
diff --git a/src/go/types/fixedbugs/issue44688.go2 b/src/go/types/testdata/fixedbugs/issue44688.go2
index 512bfcc922..512bfcc922 100644
--- a/src/go/types/fixedbugs/issue44688.go2
+++ b/src/go/types/testdata/fixedbugs/issue44688.go2
diff --git a/src/go/types/fixedbugs/issue44799.go2 b/src/go/types/testdata/fixedbugs/issue44799.go2
index 9e528a7475..9e528a7475 100644
--- a/src/go/types/fixedbugs/issue44799.go2
+++ b/src/go/types/testdata/fixedbugs/issue44799.go2
diff --git a/src/go/types/fixedbugs/issue45548.go2 b/src/go/types/testdata/fixedbugs/issue45548.go2
index b1e42497e8..b1e42497e8 100644
--- a/src/go/types/fixedbugs/issue45548.go2
+++ b/src/go/types/testdata/fixedbugs/issue45548.go2
diff --git a/src/go/types/fixedbugs/issue45635.go2 b/src/go/types/testdata/fixedbugs/issue45635.go2
index ec5cf3c5ff..ec5cf3c5ff 100644
--- a/src/go/types/fixedbugs/issue45635.go2
+++ b/src/go/types/testdata/fixedbugs/issue45635.go2
diff --git a/src/go/types/fixedbugs/issue6977.src b/src/go/types/testdata/fixedbugs/issue6977.src
index 8f4e9ba2b2..8f4e9ba2b2 100644
--- a/src/go/types/fixedbugs/issue6977.src
+++ b/src/go/types/testdata/fixedbugs/issue6977.src
diff --git a/src/go/types/check_test.go b/src/go/types/check_test.go
index 422488744b..0f23952380 100644
--- a/src/go/types/check_test.go
+++ b/src/go/types/check_test.go
@@ -47,8 +47,8 @@ import (
var (
haltOnError = flag.Bool("halt", false, "halt on error")
listErrors = flag.Bool("errlist", false, "list errors")
- testFiles = flag.String("files", "", "comma-separated list of test files")
- goVersion = flag.String("lang", "", "Go language version (e.g. \"go1.12\"")
+ testFiles = flag.String("files", "", "comma-separated list of test files for TestManual")
+ goVersion = flag.String("lang", "", "Go language version (e.g. \"go1.12\") for TestManual")
)
var fset = token.NewFileSet()
@@ -297,9 +297,10 @@ func checkFiles(t *testing.T, sizes Sizes, goVersion string, filenames []string,
}
}
// TestCheck is for manual testing of selected input files, provided with -files.
// The accepted Go language version can be controlled with the -lang flag.
-func TestCheck(t *testing.T) {
+func TestManual(t *testing.T) {
if *testFiles == "" {
return
}
@@ -322,13 +323,14 @@ func TestIndexRepresentability(t *testing.T) {
checkFiles(t, &StdSizes{4, 4}, "", []string{"index.go"}, [][]byte{[]byte(src)})
}
-func TestTestdata(t *testing.T) { DefPredeclaredTestFuncs(); testDir(t, "testdata") }
+func TestCheck(t *testing.T) { DefPredeclaredTestFuncs(); testDir(t, "check") }
func TestExamples(t *testing.T) { testDir(t, "examples") }
func TestFixedbugs(t *testing.T) { testDir(t, "fixedbugs") }
func testDir(t *testing.T, dir string) {
testenv.MustHaveGoBuild(t)
+ dir = filepath.Join("testdata", dir)
fis, err := os.ReadDir(dir)
if err != nil {
t.Error(err)
@@ -297,9 +297,10 @@ func checkFiles(t *testing.T, sizes Sizes, goVersion string, filenames []string,
}
}
-// TestCheck is for manual testing of selected input files, provided with -files.
+// TestManual is for manual testing of selected input files, provided with
+// -files.
// The accepted Go language version can be controlled with the -lang flag.